"""
Scraper for Pennsylvania Supreme Court
CourtID: pa
Court Short Name: pa
"""

import re
from datetime import date, datetime, timedelta
from urllib.parse import urlencode

from juriscraper.AbstractSite import logger
from juriscraper.OpinionSiteLinear import OpinionSiteLinear


class Site(OpinionSiteLinear):
    court = "Supreme"
    base_url = "https://www.pacourts.us/api/opinion?"
    document_url = "https://www.pacourts.us/assets/opinions/{}/out/{}"
    days_interval = 1
    api_dt_format = "%Y-%m-%dT00:00:00-05:00"
    first_opinion_date = datetime(1998, 4, 27)
    judge_key = "AuthorCode"
    regional_cite_regex = re.compile(r"\d{1,3} A\.3d \d+")

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.court_id = self.__module__
        self.regex = re.compile(r"(.*)(?:[,-]?\s+Nos?\.)(.*)")
        self.status = "Published"

        now = datetime.now()
        start = now - timedelta(days=1)
        self.params = {
            "startDate": start.strftime(self.api_dt_format),
            "endDate": now.strftime(self.api_dt_format),
            "courtType": self.court,
            "postTypes": "cd,cds,co,cs,dedc,do,ds,mo,oaj,pco,rv,sd",
            "sortDirection": "-1",
        }
        self.url = f"{self.base_url}{urlencode(self.params)}"
        self.make_backscrape_iterable(kwargs)

    def _process_html(self) -> None:
        """Parses data into case dictionaries

        Note that pages returned have no pagination

        :return: None
        """
        json_response = self.html

        for cluster in json_response["Items"]:
            disposition_date = cluster["DispositionDate"].split("T")[0]
            title = cluster["Caption"]
            name, docket = self.parse_case_title(title)
            # A.3d cites seem to exist only for pasuperct
            cite = ""
            if cite_match := self.regional_cite_regex.search(title):
                cite = cite_match.group(0)

            for op in cluster["Postings"]:
                per_curiam = False
                author_str = ""

                if op["Author"]:
                    author_str = self.clean_judge(op["Author"][self.judge_key])
                    if author_str.lower() == "per curiam":
                        author_str = ""
                        per_curiam = True

                url = self.document_url.format(self.court, op["FileName"])
                status = self.get_status(op)
                self.cases.append(
                    {
                        "date": disposition_date,
                        "name": name,
                        "docket": docket,
                        "url": url,
                        "judge": author_str,
                        "status": status,
                        "per_curiam": per_curiam,
                        "citation": cite,
                    }
                )

        if not self.test_mode_enabled() and json_response.get("HasNext"):
            next_page = json_response["PageNumber"] + 1
            logger.info("Paginating to page %s", next_page)
            self.params["pageNumber"] = next_page
            self.url = f"{self.base_url}{urlencode(self.params)}"
            self.html = self._download()
            self._process_html()

    def parse_case_title(self, title: str) -> tuple[str, str]:
        """Separates case_name and docket_number from case string

        :param title: string from the source

        :return: A tuple with the case name and docket number
        """
        search = self.regex.search(title)
        if search:
            name = search.group(1)
            docket = search.group(2)
        else:
            name = title
            docket = ""
        return name, docket

    def get_status(self, op: dict) -> str:
        """Get status from opinion json.
        Inheriting classes have status data

        :param op: opinion json
        :return: parsed status
        """
        return self.status

    def clean_judge(self, author_str: str) -> str:
        """Cleans judge name. `pa` has a different format than
        `pasuperct` and `pacommwct`
        """
        return author_str

    def extract_from_text(self, scraped_text: str) -> dict:
        """Extract citations from text

        Be careful with citations referring to other opinions that are
        mentioned before the actual citation

        See, for example:
        https://ojd.contentdm.oclc.org/digital/api/collection/p17027coll5/id/28946/download
        """
        # For each line, keep only the part after the last colon
        cleaned_text = "\n".join(
            line.rsplit(":", 1)[-1] if ":" in line else line
            for line in scraped_text.splitlines()
        )

        pattern = re.compile(
            r"""
                    (?:
                        review\s+from\s+the\s+
                        |Order\s+of(?:\s+the)?\s+
                        |Appeal\s+from\s+the(?:\s[Oo]rder\s+of\s+the)?\s+
                     )
                    (?P<lower_court>.*?)(?=\s*(?:\.|at|entered|Order|,))
                    """,
            re.X | re.DOTALL,
        )
        result = {}
        if match := pattern.search(cleaned_text):
            lower_court = re.sub(
                r"\s+", " ", match.group("lower_court")
            ).strip()

            if lower_court in ["Superior Court", "Commonwealth Court"]:
                lower_court = "Pennsylvania " + lower_court

            result["Docket"] = {"appeal_from_str": lower_court}

        return result

    def _download_backwards(self, dates: tuple[date]) -> None:
        """Modify GET querystring for desired date range

        :param dates: (start_date, end_date) tuple
        :return None
        """
        start, end = dates
        self.params["startDate"] = start.strftime(self.api_dt_format)
        self.params["endDate"] = end.strftime(self.api_dt_format)
        self.url = f"{self.base_url}{urlencode(self.params)}"
        logger.info("Backscraping for range %s %s", *dates)
        self.html = self._download()
        self._process_html()



import re

from juriscraper.OpinionSiteLinear import OpinionSiteLinear


class Site(OpinionSiteLinear):
    court_code = "S"
    division = ""
    date_regex = re.compile(r" \d\d?/\d\d?/\d\d| filed")

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.court_id = self.__module__
        self.url = f"https://www.courts.ca.gov/cms/opinions.htm?Courts={self.court_code}"
        self.status = "Published"
        self.request["verify"] = False
        self.should_have_results = True

    def _process_html(self) -> None:
        for row in self.html.xpath("//table/tr[not(th)]"):
            name = row.xpath(".//*[@class='op-title']/text()")[0]

            split = self.date_regex.split(name)[0]
            if "P. v. " in split:
                case_name = split.replace("P. ", "People ")
            else:
                case_name = split

            url = row.xpath(".//a[@class='op-link']/@href")[0]
            date_filed = row.xpath(".//*[@class='op-date']/text()")[0]
            docket = row.xpath(".//*[@class='op-case']/text()")[0]
            case = {
                "name": case_name,
                "url": url,
                "date": date_filed,
                "docket": docket,
            }
            if self.division:
                case["division"] = self.division

            self.cases.append(case)

    def extract_from_text(self, scraped_text: str) -> dict:
        """Extract lower court and case number from the scraped text.

        :param scraped_text: The text to extract from.
        :return: A dictionary with the metadata.
        """
        pattern = re.compile(
            r"S\d+\s*\n"
            r"(?P<lower_court>.+?)\s*$"
            r"(\s*\n\s*)"
            r"(?P<lower_court_number>[A-Z0-9]{4,})\s*$",
            re.MULTILINE,
        )

        lower_court = ""
        lower_court_number = ""

        if match := pattern.search(scraped_text):
            lower_court = re.sub(
                r"\s+", " ", match.group("lower_court")
            ).strip()
            lower_court_number = match.group("lower_court_number").strip()

        result = {}
        if lower_court or lower_court_number:
            if lower_court:
                result["Docket"] = {}
                result["Docket"]["appeal_from_str"] = lower_court
            if lower_court_number:
                result["OriginatingCourtInformation"] = {}
                result["OriginatingCourtInformation"]["docket_number"] = (
                    lower_court_number
                )

        return result



"""
Author: Michael Lissner
Date created: 2013-04-05
Revised by Taliah Mirmalek on 2014-02-07
Scraper for the Supreme Court of Arizona
CourtID: ariz
Court Short Name: Ariz.
"""

import re

from juriscraper.lib.string_utils import titlecase
from juriscraper.OpinionSiteLinear import OpinionSiteLinear


class Site(OpinionSiteLinear):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.court_id = self.__module__
        self.url = "http://www.azcourts.gov/opinions/SearchOpinionsMemoDecs.aspx?court=999"
        self.should_have_results = True

    def _process_html(self) -> None:
        """Parse HTML into case objects

        :return: None
        """
        # Extract download URLs
        download_urls_path = '//a[contains(@id , "hypCaseNum")]/@href'
        download_urls = self.html.xpath(download_urls_path)

        # Extract case names
        case_names_path = '//span[contains(@id , "lblTitle")]//text()'
        case_names = [
            titlecase(t.upper()) for t in self.html.xpath(case_names_path)
        ]

        # Extract case dates
        case_dates_path = '//span[contains(@id , "FilingDate")]//text()'
        case_dates = list(self.html.xpath(case_dates_path))

        # Extract precedential statuses
        precedential_statuses = []
        precedential_statuses_path = '//*[contains(@id, "DecType")]/text()'
        for s in self.html.xpath(precedential_statuses_path):
            if "OPINION" in s:
                precedential_statuses.append("Published")
            elif "MEMORANDUM" in s:
                precedential_statuses.append("Unpublished")
            else:
                precedential_statuses.append("Unknown")

        # Extract docket numbers
        docket_numbers_path = '//a[contains(@id , "hypCaseNum")]//text()'
        docket_numbers = list(self.html.xpath(docket_numbers_path))

        # Build cases list
        for i in range(len(download_urls)):
            case = {
                "name": case_names[i],
                "date": case_dates[i],
                "status": precedential_statuses[i],
                "docket": docket_numbers[i],
                "url": download_urls[i],
            }
            self.cases.append(case)

    def extract_from_text(self, scraped_text: str) -> dict:
        """Extract lower court and judge from the scraped text.

        :param scraped_text: The text to extract from.
        :return: A dictionary with the metadata.
        """
        lower_court_pattern = re.compile(
            r"""
            Appeal\s+from\s+the\s+(?P<lower_court>[^\n]+)\n\s*
            The\s+(?:Honorable\s+)?(?P<lower_court_judge>[^,]+),\s+Judge[^\n]*\n\s*
            No\.\s+(?P<lower_court_number>[^\s]+)
            """,
            re.X | re.MULTILINE | re.DOTALL,
        )

        result = {}

        if match := lower_court_pattern.search(scraped_text):
            lower_court = re.sub(
                r"\s+", " ", match.group("lower_court")
            ).strip()

            lower_court_judge = match.group("lower_court_judge").strip()
            lower_court_number = match.group("lower_court_number").strip()

            if lower_court:
                result["Docket"] = {"appeal_from_str": lower_court}
            if lower_court_judge:
                result.setdefault("OriginatingCourtInformation", {})[
                    "assigned_to_str"
                ] = lower_court_judge
            if lower_court_number:
                result.setdefault("OriginatingCourtInformation", {})[
                    "docket_number"
                ] = lower_court_number

        return result



"""
Scraper for Massachusetts Appeals Court
CourtID: massapp
Court Short Name: MS
Author: Andrei Chelaru
Court Contact: SJCReporter@sjc.state.ma.us (617) 557-1030
Reviewer: mlr
Date: 2014-07-12
History:
    - Update 2023-01-28 by William E. Palin
"""

from datetime import datetime

from juriscraper.opinions.united_states.state import mass


class Site(mass.Site):
    court_name = "Appeals Court"
    first_opinion_date = datetime(2017, 6, 15)



"""
History:
 - 2014-08-05: Adapted scraper to have year-based URLs.
 - 2023-11-18: Fixed and updated
 - 2025-04-23: implement extract_from_text, grossir
 - 2025-09-23: add lower court extraction, luism
"""

import re
from datetime import datetime, timedelta

from juriscraper.AbstractSite import logger
from juriscraper.OpinionSiteLinear import OpinionSiteLinear


class Site(OpinionSiteLinear):
    court_code = "p17027coll3"
    base_url = "https://cdm17027.contentdm.oclc.org/digital/api/search/collection/{}/searchterm/{}-{}/field/dated/mode/exact/conn/and/maxRecords/200"
    # technically they have an 1870 case but just one
    first_opinion_date = datetime(1997, 8, 12)
    days_interval = 15

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.court_id = self.__module__
        today = datetime.today()
        self.url = self.format_url(today - timedelta(15), today)
        self.make_backscrape_iterable(kwargs)

    def _process_html(self):
        for row in self.html["items"]:
            docket, name, citation, date = (
                x["value"] for x in row["metadataFields"]
            )
            if not name:
                # Happens on rows like:
                # "Miscellaneous Supreme Court dispositions, June 10 and 13, 2024"
                logger.info("Skipping row '%s'", docket)
                continue

            judge, disposition, status, lower_court_number = self.get_details(
                row
            )
            per_curiam = False
            if judge and judge == "PC" or "per curiam" in judge.lower():
                per_curiam = True
                judge = ""

            self.cases.append(
                {
                    "name": name,
                    "date": date,
                    "docket": docket.split(",")[0],
                    "url": f"https://ojd.contentdm.oclc.org/digital/api/collection/{row['collectionAlias']}/id/{row['itemId']}/download",
                    "citation": citation,
                    "judge": judge,
                    "per_curiam": per_curiam,
                    "status": status,
                    "disposition": disposition,
                    "lower_court_number": lower_court_number,
                }
            )

    def get_details(self, row: dict) -> tuple[str, str, str, str]:
        """Makes a secondary request to get details for a single
        opinion

        :param row: the JSON records, to get the item id for the request
            or the JSON object in tests
        :return: a tuple containing, if it has a valid value
            - judge
            - disposition
            - status
            - lower court number (only for `or`)
        """
        if self.test_mode_enabled():
            if not row.get("detailJson"):
                return (
                    "placeholder judge",
                    "placeholder disposition",
                    "Unknown",
                    "placeholder lower court number",
                )
            # Some test cases have their detail data manually copy pasted
            json = row["detailJson"]
        else:
            item_id = row["itemId"]
            url = f"https://cdm17027.contentdm.oclc.org/digital/api/collections/{self.court_code}/items/{item_id}/false"
            logger.debug("Getting detail JSON from %s", url)
            self._request_url_get(url)
            json = self.request["response"].json()

        if len(json["fields"]) == 1:
            fields = json["parent"]["fields"]
        else:
            fields = json["fields"]

        judge, disposition, status, lower_court_number = "", "", "Unknown", ""
        for field in fields:
            if field["key"] == "judge":
                judge = field["value"]
            elif field["key"] == "type":
                if field["value"] in [
                    "Nonprecedential opinion",
                    "Unpublished",
                ]:
                    status = "Unpublished"
                else:
                    status = "Published"
            elif field["key"] == "descri":
                disposition = field["value"]
            elif (
                field["key"] == "relhapt"
                # For orctapp this field may be populated with consolidated docket
                # numbers
                and self.court_id.endswith("or")
                and not field["value"].startswith("S")
            ):
                lower_court_number = field["value"]

        return judge, disposition, status, lower_court_number

    def _download_backwards(self, dates: tuple) -> None:
        logger.info("Backscraping for range %s %s", *dates)
        self.url = self.format_url(*dates)
        self.html = self._download()
        self._process_html()

    def format_url(self, start_date: datetime, end_date: datetime) -> str:
        """
        Creates a date range URL by formatting input dates
        """
        start = datetime.strftime(start_date, "%Y%m%d")
        end = datetime.strftime(end_date, "%Y%m%d")
        return self.base_url.format(self.court_code, start, end)

    def extract_from_text(self, scraped_text: str) -> dict:
        """Extract citations from text

        Be careful with citations referring to other opinions that are
        mentioned before the actual citation

        See, for example:
        https://ojd.contentdm.oclc.org/digital/api/collection/p17027coll5/id/28946/download
        """
        pattern = re.compile(
            r"""
                    (?:
                        review\s+from\s+the\s+
                        |On\s+appeal\s+from\s+the\s+
                     )
                    (?P<lower_court>[^.]+?)
                    (?=\s*[.,])
                    """,
            re.X,
        )
        regex = r"\n\s+(?P<cite>\d+ P3d \d+)\s+\n"

        result = {}
        if match := pattern.search(scraped_text):
            lower_court = re.sub(
                r"\s+", " ", match.group("lower_court")
            ).strip()
            if lower_court in ["Court of Appeals", "Tax Court"]:
                lower_court = "Oregon " + lower_court
            result["Docket"] = {"appeal_from_str": lower_court}

        if match := re.search(regex, scraped_text[:1000]):
            result["Citation"] = match.group("cite")

        return result



"""
CourtID: ncbizct
Court Short Name: North Carolina Business Court
Author: Kevin Ramirez
History:
    2025-05-06, quevon24: First version
"""

import re
from datetime import date
from urllib.parse import urlencode

from juriscraper.lib.string_utils import titlecase
from juriscraper.OpinionSiteLinear import OpinionSiteLinear


class Site(OpinionSiteLinear):
    days_interval = 7

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.court_id = self.__module__
        self.url = "https://www.nccourts.gov/documents/business-court-opinions"
        self.first_opinion_date = date(1996, 10, 24)
        self.make_backscrape_iterable(kwargs)
        self.should_have_results = True

    def _process_html(self):
        for row in self.html.xpath(
            ".//div[contains(@class,'list__items')]/article"
        ):
            # Extract case name and citation
            case_string = (
                row.xpath(".//h5[contains(@class,'list__title')]/a")[0]
                .text_content()
                .strip()
            )
            case_name, citation = self.extract_case_and_citation(case_string)

            # Extract other data
            date_filed = row.xpath(".//time")[0].text_content().strip()
            # In the same span we can find the docket number, the lower court and the author
            span_text = (
                row.xpath(".//div[@class='meta']/span[4]")[0]
                .text_content()
                .strip()
            )
            docket_number = span_text.split("(", 1)[0].strip()

            start_parentheses = span_text.find("(")
            end_parentheses = span_text.find(")")

            author_str = ""
            lower_courts = []
            if start_parentheses != -1 and end_parentheses != -1:
                text_in_parentheses = span_text[
                    start_parentheses + 1 : end_parentheses
                ].strip()
                parts = text_in_parentheses.split(" - ", 1)

                if len(parts) > 0:
                    lower_court_parts = parts[0].strip().split(",")
                    for court in lower_court_parts:
                        lower_courts.append(f"{court} County Court")

                if len(parts) > 1:
                    author_str = parts[1].strip()

            status = row.xpath(".//span[6]")[0].text_content().strip()
            download_url = row.xpath(
                ".//div[contains(@class,'file file--teaser')]/a/@href"
            )[0]

            self.cases.append(
                {
                    "name": titlecase(case_name),
                    "docket": docket_number,
                    "url": download_url,
                    "date": date_filed,
                    "citation": citation,
                    "status": status,
                    "author": author_str,
                    "lower_court": ", ".join(lower_courts),
                }
            )

    def extract_case_and_citation(self, case_string):
        """Extract citations and clean up case name

        Possible strings:
        BRADLEY V. U.S. PACKAGING, INC., et al. 1998 NCBC 3
        FRAZIER v. BEARD 1996 NCBC 1
        ATKORE INT'L, INC. v. DINKHELLER, 2025 NCBC 20
        """
        case_string = case_string.strip()
        citation_match = re.search(r"(\d{4} NCBC \d+)$", case_string)

        if citation_match:
            citation = citation_match.group(1)
            case_name = case_string[: citation_match.start()].strip()
            case_name = case_name.rstrip(", ").strip()
        else:
            citation = ""
            case_name = case_string

        return case_name, citation

    def _download_backwards(self, dates: tuple[date, date]) -> None:
        """Build URL with year input and scrape

        :param dates: (start_date, end_date) tuple
        :return None
        """
        params = {
            "field_publish_date_value": dates[0].strftime("%m/%d/%Y"),
            "field_publish_date_value_1": dates[1].strftime("%m/%d/%Y"),
        }
        self.url = f"{self.url}?{urlencode(params)}"
        self.html = self._download()
        self._process_html()



from datetime import datetime

from juriscraper.opinions.united_states.state import nm


class Site(nm.Site):
    court_code = "183"
    first_opinion_date = datetime(1967, 3, 26)

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.court_id = self.__module__



from juriscraper.opinions.united_states.federal_appellate import ca6


class Site(ca6.Site):
    bap_scraper = True

    # See https://www.ca6.uscourts.gov/bankruptcy-appellate-panel
    initials_to_judges = {
        "RSM": "Randal S. Mashburn",
        "SHB": "Suzanne H. Bauknight",
        "JLC": "Jimmy Croom",
        "JTG": "John T. Gregg",
        "JPG": "John P. Gustafson",
        "CRM": "Charles R. Merrill",
    }

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.should_have_results = False



"""
Scraper for Massachusetts Superior Court
CourtID: masssuperct
Court Short Name: MS
Author: Luis Manzur
Court Contact: SJCReporter@sjc.state.ma.us (617) 557-1030
Date: 2025-07-16
History:
    - Created by luism
"""

from datetime import datetime

from juriscraper.opinions.united_states.state import mass


class Site(mass.Site):
    court_name = "Superior Court"
    first_opinion_date = datetime(2017, 6, 20)



#  Scraper for Georgia Supreme Court
# CourtID: ga
# Court Short Name: ga

import re
from datetime import date

from juriscraper.AbstractSite import logger
from juriscraper.lib.string_utils import titlecase
from juriscraper.OpinionSiteLinear import OpinionSiteLinear


class Site(OpinionSiteLinear):
    url_template = "https://www.gasupreme.us/opinions/{}-opinions/"
    first_opinion_year = 2017

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.court_id = self.__module__
        self.url = self.url_template.format(date.today().year)
        self.status = "Published"
        self.make_backscrape_iterable(kwargs)

    def _process_html(self) -> None:
        for link in self.html.xpath("//li/a[contains(@href, '.pdf')]"):
            url = link.get("href")
            # Expected title content:
            # - "S20A1505, S20A1506. PENDER v. THE STATE"
            # - "S21A0306. BELL v. RAFFENSPERGER"
            title = link.text_content()

            if not title:
                logger.info("No link title for row %s", url)
                continue

            dockets = re.findall(r"S?\d{2}\w\d{4}", title)
            if not dockets:
                # Try this only when the <a> doesn't include the docket;
                # if done always, may pick up extra info like
                # "Reinstatement issued" or "Concurral issued"
                title = link.xpath("string(..)")
                dockets = re.findall(r"S?\d{2}\w\d{4}", title)

            if not dockets or "SUMMARY" in title:
                # Skip links to weekly summaries or cases without a docket
                logger.info("Skip summary row %s", title)
                continue

            docket = ", ".join(dockets)
            name = title.split(dockets[-1])[-1].strip("., ")
            # Expected summary content:
            # - "October 19, 2021—SUMMARIES for NOTEWORTHY OPINIONS"
            # - "July 7, 2021"
            # - "February 15, 2021 – SUMMARIES for NOTEWORTHY OPINIONS"
            summary = link.xpath(
                ".//parent::li/parent::ul/preceding-sibling::h3[1]/following-sibling::p"
            )[0].text_content()
            # Character separator for dates from summary text could be:
            # - dash: "-"
            # - hyphen: "—"
            # - character U+2013: "–"
            date_str = (
                summary.split("–")[0].split("—")[0].split("-")[0].strip()
            )
            self.cases.append(
                {
                    "date": date_str,
                    "docket": docket,
                    "name": titlecase(name),
                    "url": url,
                }
            )

    def _download_backwards(self, year: int) -> None:
        self.url = self.url_template.format(year)
        logger.info("Backscraping for year %s %s", year, self.url)
        self.html = self._download()
        self._process_html()

    def make_backscrape_iterable(self, kwargs: dict):
        if kwargs.get("backscrape_start"):
            start = int(kwargs["backscrape_start"])
        else:
            start = self.first_opinion_year

        if kwargs.get("backscrape_end"):
            end = int(kwargs["backscrape_end"])
        else:
            end = date.today().year - 1

        if start == end:
            end = start + 1

        self.back_scrape_iterable = range(start, end)

    def extract_from_text(self, scraped_text: str) -> dict:
        """Extract the state citation from the document's text

        :param scraped_text: the extracted text
        :return: a dictionary, empty or with expected Citation key
        """
        if match := re.search(r"\d+ Ga. \d+", scraped_text[:50]):
            return {"Citation": match.group(0)}
        else:
            return {}



"""
Scraper for New York Court of Appeals
CourtID: ny
Court Short Name: NY
History:
 2015-10-27  Created by Andrei Chelaru
"""

from datetime import date

from juriscraper.opinions.united_states.state.nyappterm_1st import (
    Site as NySite,
)


class Site(NySite):
    first_opinion_date = date(2003, 10, 27)
    days_interval = 180

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.court = "Court of Appeals"
